package com.ruoyi.feeagreement.service;

import java.util.List;
import com.ruoyi.feeagreement.domain.TWarehouseFeeAgreementTypeBusinessDetailFormula;

/**
 * 费用协议从从从Service接口
 * 
 * @author dongyongwei
 * @date 2021-08-02
 */
public interface ITWarehouseFeeAgreementTypeBusinessDetailFormulaService 
{
    /**
     * 查询费用协议从从从
     * 
     * @param fId 费用协议从从从ID
     * @return 费用协议从从从
     */
    public TWarehouseFeeAgreementTypeBusinessDetailFormula selectTWarehouseFeeAgreementTypeBusinessDetailFormulaById(Long fId);

    /**
     * 查询费用协议从从从列表
     * 
     * @param tWarehouseFeeAgreementTypeBusinessDetailFormula 费用协议从从从
     * @return 费用协议从从从集合
     */
    public List<TWarehouseFeeAgreementTypeBusinessDetailFormula> selectTWarehouseFeeAgreementTypeBusinessDetailFormulaList(TWarehouseFeeAgreementTypeBusinessDetailFormula tWarehouseFeeAgreementTypeBusinessDetailFormula);

    /**
     * 新增费用协议从从从
     * 
     * @param tWarehouseFeeAgreementTypeBusinessDetailFormula 费用协议从从从
     * @return 结果
     */
    public int insertTWarehouseFeeAgreementTypeBusinessDetailFormula(TWarehouseFeeAgreementTypeBusinessDetailFormula tWarehouseFeeAgreementTypeBusinessDetailFormula);

    /**
     * 修改费用协议从从从
     * 
     * @param tWarehouseFeeAgreementTypeBusinessDetailFormula 费用协议从从从
     * @return 结果
     */
    public int updateTWarehouseFeeAgreementTypeBusinessDetailFormula(TWarehouseFeeAgreementTypeBusinessDetailFormula tWarehouseFeeAgreementTypeBusinessDetailFormula);

    /**
     * 批量删除费用协议从从从
     * 
     * @param fIds 需要删除的费用协议从从从ID
     * @return 结果
     */
    public int deleteTWarehouseFeeAgreementTypeBusinessDetailFormulaByIds(Long[] fIds);

    /**
     * 删除费用协议从从从信息
     * 
     * @param fId 费用协议从从从ID
     * @return 结果
     */
    public int deleteTWarehouseFeeAgreementTypeBusinessDetailFormulaById(Long fId);
}
